"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const get_log_1 = __importDefault(require("./js/get-log"));
const begin_transaction_1 = __importDefault(require("./js/begin-transaction"));
const commit_transaction_1 = __importDefault(require("./js/commit-transaction"));
const rollback_transaction_1 = __importDefault(require("./js/rollback-transaction"));
const constants_1 = require("./js/constants");
const connect = async (pool, specific) => {
    var _a;
    const log = get_log_1.default('connect');
    log.debug('configuring RDS data service client');
    const { RDSDataService, escapeId, escape, fullJitter, executeStatement, coercer } = specific;
    const { dbClusterOrInstanceArn, awsSecretStoreArn, databaseName, eventsTableName = 'events', snapshotsTableName = 'snapshots', secretsTableName, bucketSize, ...rdsConfig } = (_a = pool.config) !== null && _a !== void 0 ? _a : {};
    pool.bucketSize = bucketSize;
    if (!Number.isInteger(pool.bucketSize) || pool.bucketSize < 1) {
        pool.bucketSize = constants_1.DEFAULT_BUCKET_SIZE;
    }
    const rdsDataService = new RDSDataService(rdsConfig);
    Object.assign(pool, {
        rdsDataService,
        dbClusterOrInstanceArn,
        awsSecretStoreArn,
        databaseName,
        eventsTableName,
        secretsTableName,
        snapshotsTableName,
        fullJitter,
        coercer,
        executeStatement: executeStatement.bind(null, pool),
        beginTransaction: begin_transaction_1.default,
        commitTransaction: commit_transaction_1.default,
        rollbackTransaction: rollback_transaction_1.default,
        escapeId,
        escape
    });
    log.debug('RDS data service client configured');
};
exports.default = connect;
