"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const os_1 = require("os");
const resolve_eventstore_base_1 = require("resolve-eventstore-base");
const get_log_1 = __importDefault(require("./get-log"));
const drop = async ({ databaseName, eventsTableName, snapshotsTableName, executeStatement, escapeId }) => {
    const log = get_log_1.default(`dropEventStore`);
    const databaseNameAsId = escapeId(databaseName);
    const eventsTableNameAsId = escapeId(eventsTableName);
    const threadsTableNameAsId = escapeId(`${eventsTableName}-threads`);
    const freezeTableNameAsId = escapeId(`${eventsTableName}-freeze`);
    const snapshotsTableNameAsId = escapeId(snapshotsTableName);
    const aggregateIdAndVersionIndexName = escapeId(`${eventsTableName}-aggregateIdAndVersion`);
    const aggregateIndexName = escapeId(`${eventsTableName}-aggregateId`);
    const aggregateVersionIndexName = escapeId(`${eventsTableName}-aggregateVersion`);
    const typeIndexName = escapeId(`${eventsTableName}-type`);
    const timestampIndexName = escapeId(`${eventsTableName}-timestamp`);
    const statements = [
        `DROP TABLE ${databaseNameAsId}.${eventsTableNameAsId}`,
        `DROP INDEX IF EXISTS ${databaseNameAsId}.${aggregateIdAndVersionIndexName}`,
        `DROP INDEX IF EXISTS ${databaseNameAsId}.${aggregateIndexName}`,
        `DROP INDEX IF EXISTS ${databaseNameAsId}.${aggregateVersionIndexName}`,
        `DROP INDEX IF EXISTS ${databaseNameAsId}.${typeIndexName}`,
        `DROP INDEX IF EXISTS ${databaseNameAsId}.${timestampIndexName}`,
        `DROP TABLE ${databaseNameAsId}.${threadsTableNameAsId}`,
        `DROP TABLE ${databaseNameAsId}.${snapshotsTableNameAsId}`,
        `DROP TABLE IF EXISTS ${databaseNameAsId}.${freezeTableNameAsId}`
    ];
    const errors = [];
    for (const statement of statements) {
        try {
            await executeStatement(statement);
        }
        catch (error) {
            if (error != null) {
                if (/Table.*? does not exist$/i.test(error.message)) {
                    throw new resolve_eventstore_base_1.EventstoreResourceNotExistError(`duplicate event store resource drop detected`);
                }
                else {
                    log.error(error.message);
                    log.verbose(error.stack);
                }
                errors.push(error);
            }
        }
    }
    if (errors.length > 0) {
        throw new Error(errors.map(error => error.stack).join(os_1.EOL));
    }
};
exports.default = drop;
