"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const os_1 = require("os");
const get_log_1 = __importDefault(require("../js/get-log"));
const destroy = async (pool, options) => {
    const log = get_log_1.default(`resource: destroy`);
    const { executeStatement, connect, RDSDataService, escapeId, escape, fullJitter, coercer, dispose } = pool;
    log.debug(`configuring adapter with environment privileges`);
    const adminPool = {
        config: {
            region: options.region,
            awsSecretStoreArn: options.awsSecretStoreAdminArn,
            dbClusterOrInstanceArn: options.dbClusterOrInstanceArn,
            databaseName: options.databaseName,
            eventsTableName: options.eventsTableName,
            secretsTableName: options.secretsTableName,
            snapshotsTableName: options.snapshotsTableName
        }
    };
    log.debug(`connecting the adapter`);
    await connect(adminPool, {
        RDSDataService,
        escapeId,
        escape,
        fullJitter,
        executeStatement,
        coercer
    });
    let alterSchemaError = null;
    let dropSchemaError = null;
    try {
        log.debug(`altering schema owner`);
        await executeStatement(adminPool, `ALTER SCHEMA ${escapeId(options.databaseName)} OWNER TO SESSION_USER`);
    }
    catch (error) {
        alterSchemaError = error;
    }
    try {
        log.debug(`dropping schema with all its tables`);
        await executeStatement(adminPool, `DROP SCHEMA ${escapeId(options.databaseName)} CASCADE`);
    }
    catch (error) {
        dropSchemaError = error;
    }
    if (alterSchemaError != null || dropSchemaError != null) {
        const error = new Error();
        error.message = `${alterSchemaError != null ? `${alterSchemaError.message}${os_1.EOL}` : ''}${dropSchemaError != null ? `${dropSchemaError.message}${os_1.EOL}` : ''}`;
        log.error(error.message);
        log.verbose(error.stack || error.message);
        throw error;
    }
    log.debug(`disposing the adapter`);
    await dispose(adminPool);
    log.debug(`resource destroyed successfully`);
};
exports.default = destroy;
